# Azure Service Crates

Rust crates for accessing [Azure services](https://azure.microsoft.com/services/). These crates are client libraries generated by [AutoRust](autorust) using the web service [specifications](https://github.com/Azure/azure-rest-api-specs/tree/master/specification). The specifications are divided into two categories - [control plane and data plane](https://docs.microsoft.com/azure/azure-resource-manager/management/control-plane-and-data-plane). "You use the control plane to manage resources in your subscription. You use the data plane to use capabilities exposed by your instance of a resource type."

When this document was last updated, there were 202 [control plane crates](mgmt) with 1437 [tags](api-versions.md) and 38 [data plane crates](svc) with 139 [tags](api-versions.md).

## Control Plane Crates
The control plane crates are named `azure_mgmt_${servicename}`, such as `azure_mgmt_storage`.

## Data Plane Crates
The data plane crates will be named `azure_svc_${servicename}`, such as `azure_svc_storage`.

## Examples
There are a few examples:
- azure_mgmt_storage
    - [storage_account_list](mgmt/storage/examples/storage_account_list.rs)
- azure_mgmt_resources
    - [group_create](mgmt/resources/examples/group_create.rs)
- azure_mgmt_compute
    - [vm_list](mgmt/compute/examples/vm_list.rs)
- azure_mgmt_vmware
    - [private_cloud_list](mgmt/vmware/examples/private_cloud_list.rs)
- azure_svc_batch
    - [create_task](svc/batch/examples/create_task.rs)
    - [create_task_thiserror](svc/batch/examples/create_task_thiserror.rs)
    - [list_pools](svc/batch/examples/list_pools.rs)

These services are in their own [Rust workspace](Cargo.toml), so you need to change to the `services` directory to run these examples.
``` sh
cd azure-sdk-for-rust/services
cargo run --package azure_mgmt_storage --example storage_account_list
```

## Dependencies
These crates depend on `azure_core` and `azure_identity`. Here is an example of adding `azure_svc_batch` as a dependency.

``` toml
[dependencies]
tokio = { version = "1.0", features = ["macros"] }
azure_core = "0.1"
azure_identity = "0.1"
azure_svc_batch = "0.1"
```
